/***************************************************************************
 * CVSID: $Id: libmnt.h,v 1.11 2004/05/23 14:41:54 stefanb Exp $
 *
 * libmnt.h : main() for MNT daemon
 *
 * Copyright (C) 2004 Stefan Bambach, <stefan@bambach.biz>
 *
 * Licensed under the GNU Lesser General Public License 2.1
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 **************************************************************************/
 
#ifndef __LIBMNT_H__
#define __LIBMNT_H__

#include <dbus/dbus.h>

#if defined(__cplusplus)
extern "C" {
#endif
	
#define DBUS_SERVICE_MNT "biz.bambach.Mnt"
#define DBUS_PATH_MNT_MANAGER "/biz/bambach/Mnt/Manager"
#define DBUS_INTERFACE_MNT_MANAGER "biz.bambach.Mnt.Manager"
#define DBUS_INTERFACE_MNT_VOLUME "biz.bambach.Mnt.Volume"
#define DBUS_ERROR_NO_SUCH_DEVICE "biz.bambach.Mnt.NoSuchDevice"
#define DBUS_ERROR_SYNTAX "biz.bambach.Mnt.SyntaxError"
#define DBUS_ERROR_NO_MNTPNT "biz.bambach.Mnt.NoMntPnt"

	
/** Type for function to integrate a DBusConnection into it's own mainloop. 
 *
 *  @param  udi                 Unique Device Id
 */
typedef void (*LibMntMainLoop)(DBusConnection* dbus_connection, void *user_data);


/** Type for callback when a volume is mounted.
 *
 *  @param  udi                 Unique Device Id
 */
typedef void (*LibMntVolumeMounted)(const char* udi, const char* mntpnt, void *user_data);
	

/** Type for callback when a volume is unmounted. 
 *
 *  @param  udi                 Unique Device Id
 */
typedef void (*LibMntVolumeUnmounted)(const char* udi, const char* mntpnt, void *user_data);


/** Struct to group callbacks for signals
 *
 *  Set unneeded function pointers to NULL to disable them.
 */
typedef struct LIBMNTFUNCS_
{
	/** Integrate DBusConnection into the main loop */
	LibMntMainLoop               main_loop;

	/** Device added */
	LibMntVolumeMounted          volume_mounted;

	/** Volume removed */
	LibMntVolumeUnmounted        volume_unmounted;

} LIBMNTFUNCS, *PLIBMNTFUNCS;


int mnt_init(PLIBMNTFUNCS functions, void *user_data);
int mnt_quit(void);
char **mnt_get_all_volumes(int *num_volumes);
char *mnt_get_mntpnt(char *udi);


#if defined(__cplusplus)
}
#endif

#endif /* __LIBMNT_H__ */
