#include "errmanager.h"
#include "dbug_mem.h"


emData emd;

int emInit(int logLevel, 
   int logType, 
   void (*cb)(void *ctxt, char *pFile, char *pFunc, int iLine, int level, char *fmt), 
   void *ctxt, 
   char *filename)
{
   memset(&emd, 0, sizeof(emData));

   switch(logType) {
   case EM_TYPE_SYSLOG:
      emd.logLevel    = logLevel;
      emd.logType     = logType;
      emd.errCallBack = NULL;
      emd.ctxt        = NULL;
      emd.filename    = NULL;
      openlog(PACKAGE, LOG_CONS|LOG_PID, LOG_USER);
      break;
   case EM_TYPE_STDERR:
      emd.logLevel    = logLevel;
      emd.logType     = logType;
      emd.errCallBack = NULL;
      emd.ctxt        = NULL;
      emd.filename    = NULL;
      openlog(PACKAGE, LOG_CONS|LOG_PERROR, LOG_USER);
      break;
   case EM_TYPE_CALLBACK:
      emd.logLevel    = logLevel;
      emd.logType     = logType;
      if(cb == NULL) {
         printf("Need a callback funtion by EM_TYPE_CALLBACK");
         return -1;
      } else {
         emd.errCallBack = cb;
         emd.ctxt = ctxt;
      }
      emd.filename    = NULL;
      break;
   default:
      printf("Not Supported");
      return -1;
      break;
   }
   
   return 0;
}

int reentrant=0;
void emManager(char* pFile, char* pFunc, int iLine, int level, char* fmt, ...)
{
   va_list arglist;
   char msgbuf[MAX_STRLEN];
   char debuginfos[LOG_DEBUG+1][20] = {
      "EMERG:",
      "ALERT:",
      "CRIT:",
      "ERROR:",
      "WARNING:",
      "NOTICE:",
      "INFO:",
      "DEBUG:"
   };

   if (reentrant > 0){
      return;
   }  
   reentrant++;

   va_start(arglist, fmt);
	vsnprintf(msgbuf, MAX_STRLEN, fmt, arglist);
   va_end(arglist);
   
   if(emd.logLevel >= level) {
      if(emd.logLevel == LOG_DEBUG && emd.logType != EM_TYPE_CALLBACK) {
         syslog(level, "%-9s%s:%d: %s", debuginfos[level], pFile, iLine, msgbuf);
         /*syslog(level, "%-9s%s:%s():%d: %s", debuginfos[level], pFile, pFunc, iLine, msgbuf);*/
         /*syslog(level, "[%5d;%3d.%3d] %18s:%4d %s", getpid(), getuid(), 
            getgid(), pFile, iLine, msgbuf);*/
      } else if(emd.logType != EM_TYPE_CALLBACK) {
         syslog(level, "%-9s%s", debuginfos[level], msgbuf);
         /*syslog(level, "%s", msgbuf);*/
      } else {
         emd.errCallBack(emd.ctxt, pFile, pFunc, iLine, level, msgbuf);
      }
   }
   reentrant--;
}
