/***************************************************************************
 * CVSID: $Id: mntd_dbus_error.c,v 1.4 2004/03/27 01:43:25 stefanb Exp $
 *
 * mntd_dbus_error.c : D-BUS errors for MNT daemon
 *
 * Copyright (C) 2004 Stefan Bambach, <stefan@bambach.biz>
 *
 * Licensed under the GNU General Public License 2.0
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 **************************************************************************/
 
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <dbus/dbus.h>
#include <dbus/dbus-glib.h>

#include <libmnt/libmnt.h>   /* for common defines etc. */

#include "mntd_dbus_error.h"
#include "errmanager.h"


/**
 * @defgroup DaemonErrors Error conditions
 * @ingroup MntDaemon
 * @brief Various error messages the MNT daemon can raise
 * @{
 */


/** Raise the biz.bambach.Mnt.NoSuchDevice error
 *
 *  @param  connection          D-Bus connection
 *  @param  in_reply_to         message to report error on
 *  @param  udi                 Unique device id given
 */
void mntd_dbus_error_raise_no_such_device(DBusConnection* connection,
                                 DBusMessage* in_reply_to,
                                 const char* udi)
{
	char buf[512];
	DBusMessage *reply;
	
	snprintf(buf, 511, "No device with id %s", udi);
	MSG_WARNING(buf);
	reply = dbus_message_new_error(in_reply_to, 
											"biz.bambach.Mnt.NoSuchDevice", 
											buf);
	if(reply == NULL) {
		MSG_EMERG("Out of memory");
	}
	if(!dbus_connection_send(connection, reply, NULL)) {
		MSG_EMERG("Out of memory");
	}
	dbus_message_unref(reply);
}


/** @} */
