/***************************************************************************
 * CVSID: $Id: mntd_mount.c,v 1.5 2004/04/04 14:28:51 stefanb Exp $
 *
 * mntd_mount.c : Mount helper for MNT daemon
 *
 * Copyright (C) 2004 Stefan Bambach, <stefan@bambach.biz>
 *
 * Licensed under the GNU General Public License 2.0
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 **************************************************************************/
 
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <stdlib.h>
#include <glib.h>

#include "mntd_mount.h"
#include "errmanager.h"


/**
 * @defgroup DaemonHelperMount Mount helper for mounting/unmounting devices
 * @ingroup MntDaemon
 * @brief Some helper functions for mounting and unmounting device on a directory
 * @{
 */


/** Mount device to mntpnt with options (with system() call at the moment)
 *
 * @param options               Options for mount
 * @param device                Device
 * @param mntpnt                Mount point
 * @return                      0 if successful, -1 otherwise
 */
int 
mntd_mount_mount(const char *options, const char *device, const char *mntpnt)
{
	char *command = NULL;
	char cmd[] = "/bin/mount";
	int res = -1;
	
	g_assert(options!=NULL);
	g_assert(device!=NULL);
	g_assert(mntpnt!=NULL);
	
	command = (char *) malloc(sizeof(char)*(strlen(cmd)+strlen(options)+
										strlen(device)+strlen(mntpnt)+4));
	if (command!=NULL) {
		sprintf(command, "%s %s %s %s", cmd, options, device, mntpnt);
		res = system(command);
		if (command!=NULL) {
			free(command);
			command = NULL;
		}
	}
	
	return res;
}


/** Unmount device with options (with system() call at the moment)
 *
 * @param options               Options for umount
 * @param path                  Path to umount (dir | device)
 * @return                      0 if successful, -1 otherwise
 */
int 
mntd_mount_umount(const char *options, const char *path)
{
	char *command = NULL;
	char cmd[] = "/bin/umount";
	int res = -1;
	
	g_assert(options!=NULL);
	g_assert(path!=NULL);
	
	command = (char *) malloc(sizeof(char)*(strlen(cmd)+strlen(options)+
										strlen(path)+3));
	if (command!=NULL) {
		sprintf(command, "%s %s %s", cmd, options, path);
		res = system(command);
		if (command!=NULL) {
			free(command);
			command = NULL;
		}
	}
	
	return res;
}


/** @} */
