/***************************************************************************
 * CVSID: $Id: lsmnt.c,v 1.15 2004/05/27 20:00:23 stefanb Exp $
 *
 * lsmnt.c : main() for MNT daemon
 *
 * Copyright (C) 2004 Stefan Bambach, <stefan@bambach.biz>
 *
 * Licensed under the GNU General Public License 2.0
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 **************************************************************************/
 
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <getopt.h>

#include <glib.h>
#include <dbus/dbus-glib.h>

#include <libmnt/libmnt.h>

void main_loop(DBusConnection* dbus_connection, void *user_data);
void volume_mounted(const char* udi, const char* mntpnt, void *user_data);
void volume_unmounted(const char* udi, const char* mntpnt, void *user_data);

/** for main loop integration */
void main_loop(DBusConnection* dbus_connection, void *user_data)
{
	dbus_connection_setup_with_g_main(dbus_connection, NULL);
	return;
}


/** Will be called, if volume is unmounted by MNT daemon */
void volume_mounted(const char* udi, const char* mntpnt, void *user_data)
{
	printf("volume_mounted('%s', '%s', 0x%p) called\n", udi, mntpnt, user_data);
	return;
}


/** Will be called, if volume is mounted by MNT daemon */
void volume_unmounted(const char* udi, const char* mntpnt, void *user_data)
{
	printf("volume_unmounted('%s', '%s', 0x%p) called\n", udi, mntpnt, user_data);
	return;
}

/** Callback functions for MNT daemon */
LIBMNTFUNCS mnt_functions = {	main_loop,
										volume_mounted, 
										volume_unmounted};
											
/** Entry point
 *
 *  @param  argc                Number of arguments given to program
 *  @param  argv                Arguments given to program
 *  @return                     Return code
 */
int main(int argc, char* argv[])
{
	GMainLoop* loop;
	int num_volumes=0;
	char **data = NULL;
	int i=0;
	char *udi = NULL;
	char *mntpnt = NULL;

	// print version info
	fprintf(stderr, "lsmnt v" PACKAGE_VERSION "\n");
	
	// get glib main loop
	loop = g_main_loop_new (NULL, FALSE);
	
	// initialize mnt library
	if (mnt_init(&mnt_functions, NULL) == -1) {
		fprintf(stderr, "error: mnt_init failed\n");
		exit(1);
	}

	// get all data
	data = mnt_get_all_volumes(&num_volumes);
	if (data != NULL) {
		for (i=0; i<num_volumes; i++) {
			udi = data[i];
			if (udi != NULL) {
				printf("volume%d = '%s'\n", i, udi);
				// get the mount point
				mntpnt = mnt_get_mntpnt(udi);
				if (mntpnt != NULL) {
					printf("    -> mntpnt = '%s'\n", mntpnt);
					free(mntpnt);
					mntpnt = NULL;
				}
				free(udi);
				udi = NULL;
			}
		}
		free(data);
		data = NULL;
		num_volumes = 0;
	}
	
	// start program
	g_main_loop_run(loop);
	
	// free libraries resources
	mnt_quit();
	
	// exit
	return 0;
}
